@@ -5,7 +5,7 @@
 Utilities for sending files over ssh using the scp1 protocol.
 """
 
-__version__ = '0.14.0'
+__version__ = '0.14.3'
 
 import locale
 import os
@@ -13,9 +13,6 @@ import re
 from socket import timeout as SocketTimeout
 
 
-# this is quote from the shlex module, added in py3.3
-_find_unsafe = re.compile(br'[^\w@%+=:,./~-]').search
-
 SCP_COMMAND = b'scp'
 
 PATH_TYPES = (str, bytes)
@@ -23,10 +20,28 @@ PATH_TYPES = (str, bytes)
 try:
     import pathlib
 except ImportError:
-    pass
+    pathlib = None
 else:
     PATH_TYPES += pathlib.PurePath,
+try:
+    PATH_TYPES += unicode,
+except NameError:
+    pass
 
+try:
+    from typing import IO, TYPE_CHECKING, AnyStr, Callable, Iterable, Optional, Tuple, Union
+
+    if TYPE_CHECKING:
+        import paramiko.transport
+
+    # unconditionally adding pathlib here because typing only works in python3 anyways and it's in stdlib
+    PathTypes = Union[str, bytes, "pathlib.PurePath"]
+except ImportError:
+    pass
+
+
+# this is quote from the shlex module, added in py3.3
+_find_unsafe = re.compile(br'[^\w@%+=:,./~-]').search
 
 def _sh_quote(s):
     """Return a shell-escaped version of the string `s`."""
@@ -49,7 +64,7 @@ def asbytes(s):
     """
     if isinstance(s, bytes):
         return s
-    elif pathlib and isinstance(s, pathlib.Path):
+    elif pathlib and isinstance(s, pathlib.PurePath):
         return bytes(s)
     else:
         return s.encode('utf-8')
@@ -98,6 +113,7 @@ class SCPClient(object):
     """
     def __init__(self, transport, buff_size=16384, socket_timeout=10.0,
                  progress=None, progress4=None, sanitize=_sh_quote):
+        # type: (paramiko.transport.Transport, int, float, Optional[Callable[[bytes, int, int], None]], Optional[Callable[[bytes, int, int, Tuple[str, int]], None]], Callable[[bytes], bytes]) -> None
         """
         Create an scp1 client.
 
@@ -146,6 +162,7 @@ class SCPClient(object):
 
     def put(self, files, remote_path=b'.',
             recursive=False, preserve_times=False):
+        # type: (Union[PathTypes, Iterable[PathTypes]], Union[str, bytes], bool, bool) -> None
         """
         Transfer files and directories to remote host.
 
@@ -183,6 +200,7 @@ class SCPClient(object):
         self.close()
 
     def putfo(self, fl, remote_path, mode='0644', size=None):
+        # type: (IO[AnyStr], Union[str, bytes], Union[str, bytes], Optional[int]) -> None
         """
         Transfer file-like object to remote host.
 
@@ -211,6 +229,7 @@ class SCPClient(object):
 
     def get(self, remote_path, local_path='',
             recursive=False, preserve_times=False):
+        # type: (PathTypes, Union[str, bytes], bool, bool) -> None
         """
         Transfer files and directories from remote host to localhost.
 
@@ -398,7 +417,7 @@ class SCPClient(object):
             # wait for command as long as we're open
             self.channel.sendall('\x00')
             msg = self.channel.recv(1024)
-            if not msg:  # chan closed while recving
+            if not msg:  # chan closed while receiving
                 break
             assert msg[-1:] == b'\n'
             msg = msg[:-1]
@@ -542,6 +561,7 @@ class SCPException(Exception):
 
 def put(transport, files, remote_path=b'.',
         recursive=False, preserve_times=False):
+    # type: (paramiko.transport.Transport, Union[PathTypes, Iterable[PathTypes]], Union[str, bytes], bool, bool) -> None
     """
     Transfer files and directories to remote host.
 
@@ -566,6 +586,7 @@ def put(transport, files, remote_path=b'.',
 
 def get(transport, remote_path, local_path='',
         recursive=False, preserve_times=False):
+    # type: (paramiko.transport.Transport, PathTypes, Union[str, bytes], bool, bool) -> None
     """
     Transfer files and directories from remote host to localhost.
 
